@@ -1,9 +1,14 @@
-import io, fast, spreadsheet, utils, web
+import io
+import fast
+import spreadsheet
+import tab
+import utils
+import web
 
-from tabarray import *
 from io import *
 from fast import *
 from spreadsheet import *
+from tab import *
 from utils import *
 from web import *
 
@@ -11,5 +16,6 @@ __all__ = []
 __all__.extend(io.__all__)
 __all__.extend(fast.__all__)
 __all__.extend(spreadsheet.__all__)
+__all__.extend(tab.__all__)
 __all__.extend(utils.__all__)
 __all__.extend(web.__all__)
\ No newline at end of file
