@@ -19,6 +19,7 @@ The basic structure of this module is that it contains:
 '''
 
 import os
+import csv
 
 import numpy
 
@@ -28,6 +29,8 @@ import tabular.utils as utils
 
 __all__ = ['tabarray', 'tab_colstack', 'tab_rowstack','tab_join']
 
+DEFAULT_VERBOSITY=io.DEFAULT_VERBOSITY
+
 def modifydocs(a, b, desc=''):
     """
     Convenience function for writing documentation.
@@ -208,10 +211,12 @@ class tabarray(numpy.core.records.recarray):
                 binary=None, HSVfile=None, HSVlist=None, shape=None, 
                 dtype=None, formats=None, names=None, titles=None, 
                 aligned=False, byteorder=None, comments=None, delimiter=None, 
-                delimiter_regex=None, linebreak=None, skiprows=0, usecols=None, 
-                toload=None, metadatadict=None, namesinheader=True, 
-                headerlines=None, valuefixer=None, linefixer=None, 
-                coloring=None, wrap=None):
+                lineterminator='\n', escapechar=None, quoting=csv.QUOTE_MINIMAL, 
+                quotechar='"', doublequote=True,skipinitialspace=False,
+                skiprows=0, usecols=None, toload=None, metametadata=None, 
+                namesinheader=True, headerlines=None, valuefixer=None, 
+                linefixer=None, coloring=None, wrap=None, 
+                verbosity=DEFAULT_VERBOSITY):
         """
         Unified constructor for tabarrays.
 
@@ -268,7 +273,8 @@ class tabarray(numpy.core.records.recarray):
 
                         Load data to a numpy recarray by calling::
 
-                                numpy.rec.fromarrays(records, dtype, shape, formats, names, titles, aligned, byteorder)
+                                numpy.rec.fromarrays(records, dtype, shape, 
+                                formats, names, titles, aligned, byteorder)
 
                         Fastest when passed a list of numpy arrays, rather than
                         a list of lists.
@@ -284,7 +290,9 @@ class tabarray(numpy.core.records.recarray):
                         File path to a separated variable (CSV) text file.  
                         Load data from a CSV by calling::
 
-                                tabular.io.loadSV(SVfile, comments, delimiter, delimiter_regex, linebreak, skiprows, usecols, toload, structuredheader, namesinheader, valuefixer, linefixer)
+                                tabular.io.loadSV(SVfile, comments, delimiter, 
+                                lineterminator, skiprows, usecols, metametadata, 
+                                namesinheader, valuefixer, linefixer)
 
                         **See also:**  :func:`saveSV`, 
                         :func:`tabular.io.loadSV`
@@ -356,7 +364,7 @@ class tabarray(numpy.core.records.recarray):
 
                         *	If constructing from a CSV file (e.g. ``.tsv``, 
                         	``.csv``) created by :func:`saveSV`, colorings are 
-                        	automatically parsed from the header.
+                        	automatically parsed from the header when present.
 
                         *	If constructing from a numpy binary file (e.g. 
                         	``.npz``) created by :func:`savebinary`, colorings 
@@ -376,7 +384,95 @@ class tabarray(numpy.core.records.recarray):
                         created type(:class:`tabarray`) object; this will be
                         either type(:class:`tabarray`) or the type of a 
                         subclass).
+                 
+                                
+                **usecols** :  sequence of non-negative integers, optional
 
+                    If `usecols` is not `None`, only the columns it lists are
+                    loaded, with 0 being the first column.  column names, 
+                    coloring keys, and column numbers can be mixed
+                
+                **metametadata** :  dictionary of integers or pairs of integers
+                    
+                    Specifies supplementary metametadata information for use 
+                    with SVfile loading.
+                    
+                **namesinheader** : Boolean, optional
+
+                    If `namesinheader == True` and `metadatadict == None`, then 
+                    assume metadatadict = {'names': headerlines-1}, e.g. the 
+                    column names are in the last header line.
+                    
+                **headerlines** : integer, optional
+
+                    The number of lines at the top of the file (after the first 
+                    `skiprows` lines) corresponding to the header of the file, 
+                    where metadata can be found (e.g. column names).
+
+                **valuefixer**  :  lambda function, optional
+
+                    Lambda function to apply to every value in the SV.
+                    
+                **linefixer** : lambda function, optional
+
+                    Lambda function to apply to every line in the SV.
+                    
+                **verbosity** :  integer, optional
+
+                   Sets how much detail from messages will be printed.
+                   
+                **skiprows** :  non-negative integer, optional
+
+                    The first `skiprows` lines are ignored.
+                               
+             
+                The following parameters duplicate things in the NumPy record 
+                array creation inferface:
+                
+                **names** : list of strings
+                	
+                	Sets the names of the columns.
+                	
+                **formats** :  anything that can used in numpy.rec.array 
+                construct as formats argument
+                
+                    Sets the datatypes of the columns. 
+                
+                **dtype** : numpy.dtype object
+                
+                    Sets the numpy dtype of the resulting tabarray, combining 
+                    column format and column name information.  (If you set 
+                    dtype, setting names or formats is unnecessary.)
+                
+                **byteorder**
+                
+                **aligned**
+                
+
+                The following parameters duplicate things in the Python CSV
+                module interface:
+                
+                **delimiter** : single-character string
+                
+                    Delimiter to use to reading in using SVfile
+               
+                **lineterminator** : single-character string
+                
+                    Line terminator to use when reading in using SVfile
+                    
+                **quotechar**
+
+                **escapechar**
+
+                **quoting**
+
+                **doublequote**
+
+                **skipinitialspace**
+
+                **dialect**
+                
+                
         **Special column names**
 
                         Column names that begin and end with double
@@ -446,19 +542,21 @@ class tabarray(numpy.core.records.recarray):
         elif not SVfile is None:
             chkExists(SVfile)
             # The returned DataObj is a list of numpy arrays.
-            [DataObj, givennames, givencoloring] = \
-                io.loadSV(fname=SVfile, comments=comments, delimiter=delimiter, 
-                delimiter_regex=delimiter_regex, skiprows=skiprows, 
-                usecols=usecols, toload=toload, metadatadict=metadatadict, 
+            [DataObj, metadata] = \
+                io.loadSV(fname=SVfile, names=names, dtype=dtype, shape=shape, 
+                formats=formats, titles=titles, aligned=aligned, 
+                byteorder=byteorder, comments=comments, delimiter=delimiter, 
+                lineterminator=lineterminator, escapechar=escapechar,
+                quoting=quoting,quotechar=quotechar,doublequote=doublequote,
+                skipinitialspace=skipinitialspace, skiprows=skiprows, 
+                usecols=usecols, metametadata=metametadata, 
                 namesinheader=namesinheader, headerlines=headerlines, 
-                valuefixer=valuefixer, linefixer=linefixer)
-            if (names is None) and (not givennames is None):
-                names = givennames
-            if (coloring is None) and (not givencoloring is None):
-                coloring = givencoloring
-            DataObj = numpy.rec.fromarrays(DataObj, dtype=dtype, shape=shape, 
-                      formats=formats, names=names, titles=titles, 
-                      aligned=aligned, byteorder=byteorder)
+                valuefixer=valuefixer, linefixer=linefixer,verbosity=verbosity)
+            if (names is None) and 'names' in metadata.keys() and metadata['names']:
+                names = metadata['names']
+            if (coloring is None) and 'coloring' in metadata.keys() and metadata['coloring']:
+                coloring = metadata['coloring']
+
         elif not binary is None:
             chkExists(binary)
             # Returned DataObj is a numpy ndarray with structured dtype
@@ -504,7 +602,8 @@ class tabarray(numpy.core.records.recarray):
                        coloringsInNames, ", are also attribute (column) names " 
                        "in the tabarray.  This is not allowed, and so these " 
                        "coloring keys will be deleted.  The corresponding "
-                       "columns of data will not be lost and will retain the " "same names.")
+                       "columns of data will not be lost and will retain the "
+                       "same names.")
                 for c in coloringsInNames:
                     coloring.pop(c)
                 self.coloring = coloring
@@ -654,19 +753,21 @@ class tabarray(numpy.core.records.recarray):
     renamecol.func_doc = modifydocs(renamecol, spreadsheet.renamecol, 
                                     ":func:`tabular.spreadsheet.renamecol`")
 
-    def saveSV(self, fname, comments=None, delimiter=None, linebreak=None, 
-               metadata=None, printmetadict=None, strongmetadata=False):
+    def saveSV(self, fname, comments=None, metadata=None, printmetadict=None,
+                       dialect = None, delimiter=None, doublequote=True, 
+                       lineterminator='\n', escapechar = None, quoting=csv.QUOTE_MINIMAL, 
+                       quotechar='"', skipinitialspace=False,verbosity=DEFAULT_VERBOSITY):
         """
         Save the tabarray to a single flat separated variable (CSV) text file.  
 
         Method wraps::
 
-                tabular.io.saveSV(fname, self, comments, delimiter, linebreak, metadatakeys, printmetadatadict, strongmetadata)
+                tabular.io.saveSV(fname, self, comments, delimiter, linebreak, metadatakeys, printmetadatadict)
 
         """
-        io.saveSV(fname=fname, X=self, comments=comments, delimiter=delimiter, 
-                  linebreak=linebreak, metadata=metadata, 
-                  printmetadict=printmetadict, strongmetadata=strongmetadata)
+        io.saveSV(fname,self, comments, metadata, printmetadict, 
+                        dialect, delimiter, doublequote, lineterminator, escapechar, quoting, quotechar,skipinitialspace,verbosity=verbosity)
+                        
     saveSV.func_doc = modifydocs(saveSV, io.saveSV, 
                                  ":func:`tabular.io.saveSV`")
 
